@@ -6,7 +6,6 @@ import os
 import shutil
 import sys
 import tempfile
-import time
 import unittest
 
 from dirq import QueueBase
@@ -15,48 +14,34 @@ from dirq.QueueBase import QueueBase as QueueBaseClass
 __all__ = ['TestQueueBase', 'TestQueueBaseModuleFunctions']
 
 
-class TestDirQueueBase(unittest.TestCase):
+class TestDirQueue(unittest.TestCase):
 
     def setUp(self):
-        self.path = os.getcwd() + '/directory'
-        shutil.rmtree(self.path, ignore_errors=True)
+        self.tempdir = tempfile.mkdtemp(prefix='dirq-base')
+        self.qdir = self.tempdir + '/dirq'
+        self.tempfile = self.tempdir + '/file'
 
     def tearDown(self):
-        shutil.rmtree(self.path, ignore_errors=True)
+        shutil.rmtree(self.tempdir, ignore_errors=True)
 
 
-class TestQueueBase(TestDirQueueBase):
+class TestQueueBase(TestDirQueue):
 
     def test1init(self):
         'QueueBase.__init__()'
-        path = self.path + '/aaa/bbb/ccc'
+        path = self.tempdir + '/aaa/bbb/ccc'
         QueueBaseClass(path, umask=None)
         assert os.path.exists(path) is True
 
 
-class TestQueueBaseModuleFunctions(TestDirQueueBase):
-
-    def setUp(self):
-        super(TestQueueBaseModuleFunctions, self).setUp()
-        _, self._test_file = tempfile.mkstemp()
-        try:
-            os.unlink(self._test_file)
-        except:
-            pass
-
-    def tearDown(self):
-        super(TestQueueBaseModuleFunctions, self).tearDown()
-        try:
-            os.unlink(self._test_file)
-        except:
-            pass
+class TestQueueBaseModuleFunctions(TestDirQueue):
 
     def test1_special_mkdir(self):
         'QueueBase._special_mkdir()'
-        assert QueueBase._special_mkdir(self.path) is True
-        assert QueueBase._special_mkdir(self.path) is False
+        assert QueueBase._special_mkdir(self.qdir) is True
+        assert QueueBase._special_mkdir(self.qdir) is False
         # test against a file
-        test_file = os.path.join(self.path, 'foo')
+        test_file = os.path.join(self.qdir, 'foo')
         open(test_file, 'w').write('bar')
         self.failUnlessRaises(OSError, QueueBase._special_mkdir, (test_file))
 
@@ -69,47 +54,47 @@ class TestQueueBaseModuleFunctions(TestDirQueueBase):
     def test3_file_create(self):
         'QueueBase._file_create()'
         # File in non existent directory should produce ENOENT.
-        fn = os.getcwd() + "/nodir-" + str(time.time()) + "/nofile"
+        fn = os.getcwd() + "/nodir/nofile"
         try:
             QueueBase._file_create(fn, 0, False)
         except OSError:
             error = sys.exc_info()[1]
             assert error.errno == errno.ENOENT
 
-        QueueBase._file_create(self._test_file, 0, False)
+        QueueBase._file_create(self.tempfile, 0, False)
         self.failUnlessRaises(OSError,
                               QueueBase._file_create,
-                              *(self._test_file, 0, False))
-        os.unlink(self._test_file)
+                              *(self.tempfile, 0, False))
+        os.unlink(self.tempfile)
         # utf8 data
-        QueueBase._file_create(self._test_file, 0, True)
+        QueueBase._file_create(self.tempfile, 0, True)
         self.failUnlessRaises(OSError,
                               QueueBase._file_create,
-                              *(self._test_file, 0, True))
+                              *(self.tempfile, 0, True))
 
     def test4_file_write(self):
         'QueueBase._file_write()'
-        QueueBase._file_write(self._test_file, 0, False, 'a\n'.encode())
-        os.unlink(self._test_file)
-        QueueBase._file_write(self._test_file, 0,
+        QueueBase._file_write(self.tempfile, 0, False, 'a\n'.encode())
+        os.unlink(self.tempfile)
+        QueueBase._file_write(self.tempfile, 0,
                               False, ('a' * (2 ** 10) * 10).encode())
-        os.unlink(self._test_file)
+        os.unlink(self.tempfile)
         for t in [1, [], (), {}, object]:
             self.failUnlessRaises(TypeError, QueueBase._file_write, ('', t))
 
     def test5_file_read(self):
         'QueueBase._file_read()'
         text = 'hello\n'.encode()
-        open(self._test_file, 'wb').write(text)
-        text_in = QueueBase._file_read(self._test_file, False)
+        open(self.tempfile, 'wb').write(text)
+        text_in = QueueBase._file_read(self.tempfile, False)
         self.assertEqual(text, text_in)
         # utf8
         try:
             text = 'Élément \u263A\n'.decode("utf-8")
         except AttributeError:
             text = 'Élément \u263A\n'
-        codecs.open(self._test_file, 'w', 'utf8').write(text)
-        text_in = QueueBase._file_read(self._test_file, True)
+        codecs.open(self.tempfile, 'w', 'utf8').write(text)
+        text_in = QueueBase._file_read(self.tempfile, True)
         self.assertEqual(text, text_in)
 
 
